"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const file_1 = require("./../../utils/file");
const common_1 = require("./../../utils/common");
const isVueFile = (pathname) => {
    const extension = file_1.extractExtension(pathname);
    return extension === 'vue';
};
exports.buildComponentFileContext = ({ rootDir, absolutePathname, }) => {
    const relativePathname = absolutePathname.replace(rootDir, '');
    const fileName = file_1.extractFileName(relativePathname);
    const dirName = relativePathname.replace(fileName, '');
    const name = fileName.split('.').shift();
    return {
        absolutePathname,
        relativePathname,
        dirName,
        fileName,
        name,
    };
};
exports.buildConmponentContext = ({ dirContext, componentFileContext, }) => {
    const link = exports.buildLink(Object.assign({}, componentFileContext, { distDirPrefix: dirContext.distDirPrefix }));
    const catalogPathname = buildCatalogPathname({ dirContext, link });
    return Object.assign({}, componentFileContext, { link,
        catalogPathname, existDocs: false });
};
exports.divideByDirectory = ({ filePathnames, rootDir, }) => {
    const map = new Map();
    filePathnames
        .map((pathname) => {
        return exports.buildComponentFileContext({ rootDir, absolutePathname: pathname });
    })
        .forEach((context) => {
        const { dirName } = context;
        const contextsInDir = map.get(dirName) || [];
        contextsInDir.push(context);
        map.set(dirName, contextsInDir);
    });
    return map;
};
exports.buildLink = ({ name, relativePathname, distDirPrefix, }) => {
    const slug = common_1.camelToHyphen(name);
    const pathnameList = relativePathname.split('/');
    pathnameList.pop();
    return `/${path_1.default.join(distDirPrefix, ...pathnameList, slug)}/`;
};
const buildCatalogPathname = ({ dirContext, link, }) => {
    return path_1.default.join(dirContext.catalogDir, link).replace(/\/$/, '') + '.md';
};
exports.default = ({ dirContext, }) => {
    const { rootDir, include, exclude } = dirContext;
    const vueFilePathnames = file_1.getFilePathnamesWithFilter(rootDir, {
        include,
        exclude,
    }).filter(isVueFile);
    const fileContextMap = exports.divideByDirectory({
        filePathnames: vueFilePathnames,
        rootDir,
    });
    const componentContextMap = new Map();
    for (const [dirName, fileContexts] of fileContextMap.entries()) {
        const componentContexts = fileContexts.map((componentFileContext) => {
            return exports.buildConmponentContext({ dirContext, componentFileContext });
        });
        componentContextMap.set(dirName, componentContexts);
    }
    return componentContextMap;
};
