"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const constants_1 = require("./../../constants");
exports.default = ({ environment, rootDir, include = [], exclude = [], distDirPrefix, ctx, options, }) => {
    const { sourceDir } = ctx;
    const configDir = path_1.default.join(sourceDir, '.vuepress');
    const catalogDir = path_1.default.join(ctx.tempPath, '.catalog');
    let staticDir = options.staticDir || null;
    const prefix = distDirPrefix || constants_1.DIST_DEFAULT_PREFIX;
    include = Array.isArray(include) ? include : [include];
    exclude = Array.isArray(exclude) ? exclude : [exclude];
    exclude.push(...constants_1.EXCLUDE.DEFAULT);
    if (environment.nuxt) {
        exclude.push(...constants_1.EXCLUDE.NUXT);
    }
    if (staticDir === null) {
        if (environment.vueCLI) {
            staticDir = path_1.default.join(rootDir, 'public');
        }
        if (environment.nuxt && typeof options.nuxt === 'object') {
            const nuxtConfig = require(options.nuxt.configPath);
            const nuxtRootDir = ('rootDir' in nuxtConfig
                ? nuxtConfig.rootDir
                : rootDir).replace(/\/$/, '');
            const srcDir = ('srcDir' in nuxtConfig
                ? path_1.default.join(nuxtRootDir, nuxtConfig.srcDir)
                : nuxtRootDir).replace(/\/$/, '');
            staticDir = path_1.default.join(srcDir, 'static');
        }
    }
    return {
        rootDir,
        sourceDir,
        include,
        exclude,
        configDir,
        catalogDir,
        distDirPrefix: prefix,
        staticDir,
    };
};
