"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const crypto_1 = require("crypto");
const md5 = str => {
    const md5 = crypto_1.createHash('md5');
    md5.update(str);
    return md5.digest('hex').slice(-5);
};
const buildPlaygroundComponent = ({ content, tag, RE_MARKER, ctx, }) => {
    content = content
        // remove annotation
        .replace(RE_MARKER, '')
        // ensure <style> is scoped
        .replace(/\<style([^>]*)\>/g, (match, g1) => {
        if (match.indexOf('scoped') < 0) {
            return `<style scoped${g1}>`;
        }
        return match;
    });
    if (!content.startsWith('<template>')) {
        content = `<template>${content}</template>`;
    }
    fs_1.writeFileSync(path_1.join(ctx.tempPath, `${tag}.vue`), content);
};
const parseCode = ({ rawCode, tag, RE_MARKER, }) => {
    return rawCode
        .replace(RE_MARKER, '')
        .replace(/class="language-html(?=[\s"])/, 'class="language-vue')
        .replace('<!--beforebegin-->', `<!--beforebegin--><div class="playground"><div class="stage"><${tag} /></div>`)
        .replace('<!--afterend-->', '</div><!--afterend-->');
};
exports.default = (ctx, md) => {
    const RE_MARKER = /@playground\s*/;
    const fence = md.renderer.rules.fence;
    md.renderer.rules.fence = (...args) => {
        const [tokens, idx] = args;
        const token = tokens[idx];
        const rawCode = fence(...args);
        const lang = token.info.trim().toLowerCase();
        // lang is `html` or `vue`
        if (['html', 'vue'].includes(lang)) {
            const content = token.content;
            if (content.startsWith('@playground')) {
                const tag = `ComponentPlaygroundX${md5(content)}`;
                buildPlaygroundComponent({ content, tag, RE_MARKER, ctx });
                return parseCode({ rawCode, tag, RE_MARKER });
            }
        }
        return rawCode;
    };
};
