"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const environment_1 = require("./utils/environment");
const build_1 = require("./build");
const watch_1 = require("./watch");
const logger_1 = __importDefault(require("./utils/logger"));
module.exports = (options, ctx) => {
    environment_1.setDefaultOptions(options);
    if (typeof options.rootDir !== 'string') {
        logger_1.default.error(new Error('Please set rootDir option. Because automatic project scan failed.'));
        process.exit(1);
    }
    const environment = environment_1.scanProject(options);
    const dirContext = build_1.buildDirContext({
        environment,
        rootDir: options.rootDir,
        include: options.include,
        exclude: options.exclude,
        distDirPrefix: options.distDirPrefix,
        ctx,
        options,
    });
    const componentContextMap = build_1.buildComponentContextMap({ dirContext });
    watch_1.watchComponents({ dirContext, componentContextMap });
    return Object.assign({ name: constants_1.NAME, plugins: build_1.buildPlugins({ dirContext, environment }), chainWebpack(config) {
            build_1.buildWebpackConfig({ config, options, environment, dirContext, ctx });
        },
        chainMarkdown(config) {
            build_1.buildMarkdownConfig({ config, ctx });
        }, additionalPages: build_1.buildPages({ dirContext, componentContextMap }) }, build_1.buildStatic({ dirContext }));
};
