"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const minimatch_1 = __importDefault(require("minimatch"));
exports.existPathname = (pathname) => {
    try {
        fs_1.default.statSync(pathname);
        return true;
    }
    catch (err) {
        return false;
    }
};
const createDir = (pathname) => {
    fs_1.default.mkdirSync(pathname);
};
const ensureWriteProcess = (pathname) => {
    const fileDirname = path_1.default.dirname(pathname);
    if (exports.existPathname(fileDirname)) {
        return;
    }
    ensureWriteProcess(fileDirname);
    createDir(fileDirname);
};
exports.isMatchPathname = (pathname, globs) => {
    if (globs.length === 0) {
        return false;
    }
    for (const glob of globs) {
        if (minimatch_1.default(pathname, glob, { matchBase: true, dot: true })) {
            return true;
        }
    }
    return false;
};
exports.writeFile = (pathname, data) => {
    ensureWriteProcess(pathname);
    fs_1.default.writeFileSync(pathname, data, { encoding: 'utf-8' });
};
exports.readFile = (pathname) => {
    return fs_1.default.readFileSync(pathname, { encoding: 'utf-8' });
};
exports.getDirPathnames = (dirPathname, option = {}) => {
    const { deep = true } = option;
    return fs_1.default.readdirSync(dirPathname).reduce((newPathnames, pathname) => {
        const absoluteFilePath = path_1.default.join(dirPathname, pathname);
        if (fs_1.default.statSync(absoluteFilePath).isDirectory()) {
            newPathnames.push(absoluteFilePath);
            if (deep) {
                return newPathnames.concat(exports.getDirPathnames(absoluteFilePath, option));
            }
            return newPathnames;
        }
        else {
            return newPathnames;
        }
    }, []);
};
exports.getDirPathnamesWithFilter = (dirPathname, option = {}) => {
    const { include = [], exclude = [] } = option;
    return exports.getDirPathnames(dirPathname, option)
        .filter(pathname => exclude.length === 0 || !exports.isMatchPathname(pathname, exclude))
        .filter(pathname => include.length === 0 || exports.isMatchPathname(pathname, include));
};
exports.getFilePathnames = (dirPathname, option = {}) => {
    const { deep = true } = option;
    return fs_1.default.readdirSync(dirPathname).reduce((newPathnames, pathname) => {
        const absoluteFilePath = path_1.default.join(dirPathname, pathname);
        if (fs_1.default.statSync(absoluteFilePath).isDirectory()) {
            if (deep) {
                return newPathnames.concat(exports.getFilePathnames(absoluteFilePath, option));
            }
            return newPathnames;
        }
        else {
            return newPathnames.concat(absoluteFilePath);
        }
    }, []);
};
exports.getFilePathnamesWithFilter = (dirPathname, option = {}) => {
    const { include = [], exclude = [] } = option;
    return exports.getFilePathnames(dirPathname, option)
        .filter(pathname => exclude.length === 0 || !exports.isMatchPathname(pathname, exclude))
        .filter(pathname => include.length === 0 || exports.isMatchPathname(pathname, include));
};
exports.extractFileName = (pathname) => {
    return pathname.split('/').pop() || null;
};
exports.extractExtension = (pathname) => {
    return pathname.split('.').pop() || null;
};
